@@ -1,4 +1,3 @@
-from pydantic import BaseModel
 from typing import List, Optional
 import tiktoken
 from langchain.text_splitter import RecursiveCharacterTextSplitter
@@ -6,21 +5,7 @@ import pinecone
 import openai
 from tqdm.auto import tqdm
 import os
-from .scraper import VideoRecord
-
-
-class Metadata(BaseModel):
-    title: str
-    channel_id: str
-    published: str
-    source: str
-    chunk: int
-
-class Record(BaseModel):
-    id: str
-    text: str
-    metadata: Metadata
-
+from pod_gpt.models import Record, VideoRecord, Metadata
 
 tokenizer = tiktoken.get_encoding('cl100k_base')
 
